/*
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the License).  You may not use this file except in
 * compliance with the License.
 *
 * You can obtain a copy of the license at
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL
 * Header Notice in each file and include the License file
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.
 * If applicable, add the following below the CDDL Header,
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */
package enterprise.lottery_annotation_client;

import javax.naming.InitialContext;
import javax.ejb.EJB;

import enterprise.lottery_annotation_ejb_stateful.Lottery;
import enterprise.lottery_annotation_ejb_stateless.Dice;

public class JavaClient {
    
    private static @EJB Lottery lottery;
    private static @EJB Dice dice;
    
    public static void main(String args[]) {
        JavaClient client = new JavaClient();
        if("FailOver".equalsIgnoreCase(args[0])){
            System.out.println("Running the failover test!");
            client.foTest();
        }else if("LB".equalsIgnoreCase(args[0])){
            System.out.println("Running the lb test!");
            client.lbTest();
        }else if("LB2".equalsIgnoreCase(args[0])){
            System.out.println("Running the lb test2!");
            client.lbTest2();
        }else if("FO2".equalsIgnoreCase(args[0])){
            System.out.println("Running the failover test2!");
            client.foTest2();
        }else if("DynamicLBTest".equalsIgnoreCase(args[0])){
            System.out.println("Running the dynamic lb tests!");
            client.lbTest2();
            client.waitForEnter();
            client.lbTest2();
        }
        
    }
    
    public JavaClient(){}
    
    public void lbTest(){
        InitialContext ic = null;
        for(int j = 0 ; j < 100; j++){
            
            try {
                ic = new InitialContext();
                Lottery lottery1 =
                        (Lottery) ic.lookup("enterprise.lottery_annotation_ejb_stateful.Lottery");
                lottery1.setName("Super Stinker");
                Dice dice1;
                for(int i=0; i<6; i++) {
                    dice1 =
                            (Dice) ic.lookup("enterprise.lottery_annotation_ejb_stateless.Dice");
                    lottery1.select(dice1.play());
                }
                
                String lotteryName = lottery1.getName();
                String lotteryNumber = lottery1.getNumber();
                String lotteryDate = lottery1.getDate();
                String results = "Your" + " " + lotteryName + " " +
                        "quick pick, played on" + " " + lotteryDate +
                        " " + "is" + " " + lotteryNumber;
                System.out.println(results);
                ic.close();
                ic=null;
                lottery1=null;
                dice1=null;
            } catch(Exception e) {
                System.out.println("Exception: " + e);
                e.printStackTrace();
            }
        }
    }
    
    public void lbTest2(){
        InitialContext ic = null;
        for(int j = 0 ; j < 100; j++){
            
            try {
                ic = new InitialContext();
                Lottery lottery1 =
                        (Lottery) ic.lookup("enterprise.lottery_annotation_ejb_stateful.Lottery");
                lottery1.setName("Super Stinker");
                Dice dice1;
                for(int i=0; i<6; i++) {
                    dice1 =
                            (Dice) ic.lookup("enterprise.lottery_annotation_ejb_stateless.Dice");
                    lottery1.select(dice1.play());
                }
                
                String lotteryName = lottery1.getName();
                String lotteryNumber = lottery1.getNumber();
                String lotteryDate = lottery1.getDate();
                String results = "Your" + " " + lotteryName + " " +
                        "quick pick, played on" + " " + lotteryDate +
                        " " + "is" + " " + lotteryNumber;
                System.out.println(results);
                ic.close();
                ic=null;
                lottery1=null;
                dice1=null;
                
                if(j==20){
                    waitForEnter();
                }
                
                if(j==40){
                    waitForEnter();
                }
            } catch(Exception e) {
                System.out.println("Exception: " + e);
                e.printStackTrace();
            }
        }
    }
    
    /*public void lbTest(){
        try {
            for(int i=0; i<600; i++) {
                lottery.select(dice.play());
                String lotteryName = lottery.getName();
                String lotteryNumber = lottery.getNumber();
                String lotteryDate = lottery.getDate();
                String results = "Your" + " " + lotteryName + " " +
                        "quick pick, played on" + " " + lotteryDate +
                        " " + "is" + " " + lotteryNumber;
                System.out.println(results);
            }
        } catch(Exception e) {
            System.out.println("Exception: " + e);
            e.printStackTrace();
        }
    }*/
    
    public void foTest(){
        for(int j = 0 ; j < 1000; j++){
            try {
                for(int i=0; i<6; i++) {
                    lottery.select(dice.play());
                }
                String lotteryName = lottery.getName();
                String lotteryNumber = lottery.getNumber();
                String lotteryDate = lottery.getDate();
                
                String results = "Your" + " " + lotteryName + " " +
                        "quick pick, played on" + " " + lotteryDate +
                        " " + "is" + " " + lotteryNumber;
                
                System.out.println(results);
                Thread.sleep(600);
            } catch(Exception e) {
                System.out.println("Exception: " + e);
                e.printStackTrace();
            }
        }
    }
    
    public void foTest2(){
        InitialContext ic = null;
        try{
            ic = new InitialContext();
        }catch(Exception ex){
            ex.printStackTrace();
        }        
        waitForEnter();
        for(int j = 0 ; j < 100; j++){            
            try {                
                Lottery lottery1 =
                        (Lottery) ic.lookup("enterprise.lottery_annotation_ejb_stateful.Lottery");
                lottery1.setName("Super Stinker");
                Dice dice1;
                for(int i=0; i<6; i++) {
                    dice1 =
                            (Dice) ic.lookup("enterprise.lottery_annotation_ejb_stateless.Dice");
                    lottery1.select(dice1.play());
                }
                
                String lotteryName = lottery1.getName();
                String lotteryNumber = lottery1.getNumber();
                String lotteryDate = lottery1.getDate();
                String results = "Your" + " " + lotteryName + " " +
                        "quick pick, played on" + " " + lotteryDate +
                        " " + "is" + " " + lotteryNumber;
                System.out.println(results);
                ic.close();
                ic=null;
                lottery1=null;
                dice1=null;
                
                if(j==50){
                    waitForEnter();
                }   
                ic = new InitialContext();
            } catch(Exception e) {
                System.out.println("Exception: " + e);
                e.printStackTrace();
            }
        }
    }
    
    private  static void waitForEnter(){
        try{
            System.out.println("Press <Enter> to continue ...");
            java.io.BufferedReader reader = new java.io.BufferedReader(new java.io.InputStreamReader(System.in));
            reader.readLine();
        } catch(Exception e){
            System.out.println("Exception while waiting for <Enter>:"+e.toString());
        }
    }
}
